==> haskell-concurrent-supply-0.1.8-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-3mKYXwSsThTC3GUHovsKgL
key:                  concurrent-supply-0.1.8-3mKYXwSsThTC3GUHovsKgL
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  f952fc1f3fa2cfd8be550f5f8749511c
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-8.10.3/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-8.10.3/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/concurrent-supply-0.1.8
hs-libraries:         HSconcurrent-supply-0.1.8-3mKYXwSsThTC3GUHovsKgL
depends:
    base-4.14.1.0 ghc-prim-0.6.1 hashable-1.3.0.0-AuOWFkmW3BKQo2eaHHrrX

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-supply-0.1.8-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-C6CvyF2IFB89wMk44UxxLa
key:                  concurrent-supply-0.1.8-C6CvyF2IFB89wMk44UxxLa
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  d561a2ba025886fecc7bc87d9e52fb8d
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-8.10.3/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-8.10.3/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/concurrent-supply-0.1.8
hs-libraries:         HSconcurrent-supply-0.1.8-C6CvyF2IFB89wMk44UxxLa
depends:
    base-4.14.1.0 ghc-prim-0.6.1
    hashable-1.3.0.0-C4QpLHBwsCbBQudtxc3BPD

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
